==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/portal/kotlin/inputs/MarkdownPartMetadataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.portal.kotlin.inputs

import com.pulumi.azurenative.portal.inputs.MarkdownPartMetadataArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Markdown part metadata.
 * @property inputs Input to dashboard part.
 * @property settings Markdown part settings.
 * @property type The type of dashboard part.
 * Expected value is 'Extension/HubsExtension/PartType/MarkdownPart'.
 */
public data class MarkdownPartMetadataArgs(
    public val inputs: Output<List<Any>>? = null,
    public val settings: Output<MarkdownPartMetadataSettingsArgs>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.portal.inputs.MarkdownPartMetadataArgs> {
    override fun toJava(): com.pulumi.azurenative.portal.inputs.MarkdownPartMetadataArgs =
        com.pulumi.azurenative.portal.inputs.MarkdownPartMetadataArgs.builder()
            .inputs(inputs?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .settings(settings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MarkdownPartMetadataArgs].
 */
@PulumiTagMarker
public class MarkdownPartMetadataArgsBuilder internal constructor() {
    private var inputs: Output<List<Any>>? = null

    private var settings: Output<MarkdownPartMetadataSettingsArgs>? = null

    private var type: Output<String>? = null

    /**
     * @param value Input to dashboard part.
     */
    @JvmName("vfcobctowdwjbnlr")
    public suspend fun inputs(`value`: Output<List<Any>>) {
        this.inputs = value
    }

    @JvmName("ishuklobtowiooag")
    public suspend fun inputs(vararg values: Output<Any>) {
        this.inputs = Output.all(values.asList())
    }

    /**
     * @param values Input to dashboard part.
     */
    @JvmName("oemdlmrfmknufaff")
    public suspend fun inputs(values: List<Output<Any>>) {
        this.inputs = Output.all(values)
    }

    /**
     * @param value Markdown part settings.
     */
    @JvmName("jvbglnkwmmcokkix")
    public suspend fun settings(`value`: Output<MarkdownPartMetadataSettingsArgs>) {
        this.settings = value
    }

    /**
     * @param value The type of dashboard part.
     * Expected value is 'Extension/HubsExtension/PartType/MarkdownPart'.
     */
    @JvmName("dfmxfdsuditlrdis")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Input to dashboard part.
     */
    @JvmName("wbrknwtsmswciois")
    public suspend fun inputs(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.inputs = mapped
    }

    /**
     * @param values Input to dashboard part.
     */
    @JvmName("fprxhqnurywcforp")
    public suspend fun inputs(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.inputs = mapped
    }

    /**
     * @param value Markdown part settings.
     */
    @JvmName("cyplhamtcfvwfrbf")
    public suspend fun settings(`value`: MarkdownPartMetadataSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.settings = mapped
    }

    /**
     * @param argument Markdown part settings.
     */
    @JvmName("bebmvgkavtsrbmtw")
    public suspend
    fun settings(argument: suspend MarkdownPartMetadataSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = MarkdownPartMetadataSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.settings = mapped
    }

    /**
     * @param value The type of dashboard part.
     * Expected value is 'Extension/HubsExtension/PartType/MarkdownPart'.
     */
    @JvmName("owcvmycgowoaakkr")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): MarkdownPartMetadataArgs = MarkdownPartMetadataArgs(
        inputs = inputs,
        settings = settings,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/portal/kotlin/inputs/MarkdownPartMetadataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.portal.kotlin.inputs

import com.pulumi.azurenative.portal.inputs.MarkdownPartMetadataArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Markdown part metadata.
 * @property inputs Input to dashboard part.
 * @property settings Markdown part settings.
 * @property type The type of dashboard part.
 * Expected value is 'Extension/HubsExtension/PartType/MarkdownPart'.
 */
public data class MarkdownPartMetadataArgs(
    public val inputs: Output<List<Any>>? = null,
    public val settings: Output<MarkdownPartMetadataSettingsArgs>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.portal.inputs.MarkdownPartMetadataArgs> {
    override fun toJava(): com.pulumi.azurenative.portal.inputs.MarkdownPartMetadataArgs =
        com.pulumi.azurenative.portal.inputs.MarkdownPartMetadataArgs.builder()
            .inputs(inputs?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .settings(settings?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [MarkdownPartMetadataArgs].
 */
@PulumiTagMarker
public class MarkdownPartMetadataArgsBuilder internal constructor() {
    private var inputs: Output<List<Any>>? = null

    private var settings: Output<MarkdownPartMetadataSettingsArgs>? = null

    private var type: Output<String>? = null

    /**
     * @param value Input to dashboard part.
     */
    @JvmName("cdjbabdsashcaqdg")
    public suspend fun inputs(`value`: Output<List<Any>>) {
        this.inputs = value
    }

    @JvmName("qfweewvmhqyeyehs")
    public suspend fun inputs(vararg values: Output<Any>) {
        this.inputs = Output.all(values.asList())
    }

    /**
     * @param values Input to dashboard part.
     */
    @JvmName("cwenmdpvgmmumlpp")
    public suspend fun inputs(values: List<Output<Any>>) {
        this.inputs = Output.all(values)
    }

    /**
     * @param value Markdown part settings.
     */
    @JvmName("ihayjxvbqmbukhro")
    public suspend fun settings(`value`: Output<MarkdownPartMetadataSettingsArgs>) {
        this.settings = value
    }

    /**
     * @param value The type of dashboard part.
     * Expected value is 'Extension/HubsExtension/PartType/MarkdownPart'.
     */
    @JvmName("gdwgchqrybtomrbb")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Input to dashboard part.
     */
    @JvmName("rdxsxkscnxpqrakk")
    public suspend fun inputs(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.inputs = mapped
    }

    /**
     * @param values Input to dashboard part.
     */
    @JvmName("ycscifhvvcjuvlra")
    public suspend fun inputs(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.inputs = mapped
    }

    /**
     * @param value Markdown part settings.
     */
    @JvmName("faltaaeyhjidbptt")
    public suspend fun settings(`value`: MarkdownPartMetadataSettingsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.settings = mapped
    }

    /**
     * @param argument Markdown part settings.
     */
    @JvmName("ejvypduwcxinnoln")
    public suspend
    fun settings(argument: suspend MarkdownPartMetadataSettingsArgsBuilder.() -> Unit) {
        val toBeMapped = MarkdownPartMetadataSettingsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.settings = mapped
    }

    /**
     * @param value The type of dashboard part.
     * Expected value is 'Extension/HubsExtension/PartType/MarkdownPart'.
     */
    @JvmName("ggbijbrngloljchp")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): MarkdownPartMetadataArgs = MarkdownPartMetadataArgs(
        inputs = inputs,
        settings = settings,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
